# Algora Labs SDK

[Algora Labs](https://algoralabs.com/) is a strategy development platform for financial derivatives. You can build,
test and launch complex trading strategies in minutes. The [algora-sdk](https://pypi.org/project/algora-sdk/) allows
users to programmatically access our APIs and Quant tools, including strategy development and backtesting.

## Installation

When running locally, set the following environment variables for your username and password
for [Algora Labs](https://trade.algoralabs.com/). When running code on our platform, there is no need to set these
environment variables.

```text
ALGORA_USER=username
ALGORA_PWD=password
```

## Contact

Please [Contact Us](mailto:support@algoralabs.com) if you have any questions!
